@@ -27,7 +27,7 @@ pub struct Description<FILE> {
 
 #[cfg(feature = "cli")]
 impl Description<common::File> {
-    pub(super) fn verify_config(&self) -> Result<(), super::MissingFileNameError> {
+    pub(super) fn verify_config(&self) -> Result<(), super::MissingFilename> {
         self.initialize.python_build_file_path().exists_or_err()?;
 
         self.initialize
@@ -50,7 +50,7 @@ impl Description<common::File> {
 
     pub(super) fn hashed(
         &self,
-    ) -> Result<Description<common::HashedFile>, super::MissingFileNameError> {
+    ) -> Result<Description<common::HashedFile>, super::MissingFilename> {
         let initialize = self.initialize.hashed()?;
 
         let mut jobs = Vec::new();
@@ -122,7 +122,7 @@ pub struct Initialize<FILE> {
 impl Initialize<common::File> {
     pub(crate) fn hashed(
         &self,
-    ) -> Result<Initialize<common::HashedFile>, super::MissingFileNameError> {
+    ) -> Result<Initialize<common::HashedFile>, super::MissingFilename> {
         let init_hash = hashing::filename_hash(self);
 
         let hashed_path = format!("setup_python_{init_hash}.dist").into();
@@ -145,7 +145,7 @@ impl Initialize<common::File> {
                     filename,
                 ))
             })
-            .collect::<Result<Vec<_>, super::MissingFileNameError>>()?;
+            .collect::<Result<Vec<_>, super::MissingFilename>>()?;
 
         let init = Initialize {
             python_build_file_path,
@@ -178,6 +178,9 @@ pub struct Job<FILE> {
     #[serde(default = "Default::default")]
     #[getset(get = "pub(crate)")]
     pub(super) required_files: Vec<FILE>,
+    /// slurm configuration. This level of information will override the defeaults at the outer 
+    /// most level of the configuration
+    slurm: Option<super::Slurm>
 }
 
 #[cfg(feature = "cli")]
@@ -185,7 +188,7 @@ impl Job<common::File> {
     pub(crate) fn hashed(
         &self,
         job_idx: usize,
-    ) -> Result<Job<common::HashedFile>, super::MissingFileNameError> {
+    ) -> Result<Job<common::HashedFile>, super::MissingFilename> {
         let hash = hashing::filename_hash(self);
 
         let required_files = self
@@ -206,7 +209,7 @@ impl Job<common::File> {
                     filename,
                 ))
             })
-            .collect::<Result<Vec<_>, super::MissingFileNameError>>()?;
+            .collect::<Result<Vec<_>, super::MissingFilename>>()?;
 
         let hashed_path = format!("{hash}_python_run.dist").into();
         let unhashed_path = self.python_job_file.path().into();
@@ -218,6 +221,7 @@ impl Job<common::File> {
             name: self.name().to_string(),
             python_job_file,
             required_files,
+            slurm: self.slurm.clone()
         };
 
         Ok(job)
